IQM Benchmarks
##########

:Release: |release|
:Date: |today|
:Source Code: `<https://github.com/iqm-finland/iqm-benchmarks>`_

Quantum Characterization, Verification, and Validation (QCVV) tools for quantum computing.
Developed by `IQM <https://meetiqm.com/>`_.

Contents
========

.. toctree::
   :maxdepth: 2

   readme
   API
   license

.. toctree::
   :maxdepth: 1

   changelog


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
